from zope.app.form.browser.textwidgets import DatetimeWidget
from zope.app.pagetemplate import ViewPageTemplateFile
from DateTime import DateTime
from zope.app.datetimeutils import parseDatetimetz
from zope.app.form.interfaces import WidgetInputError

class dtwidget(DatetimeWidget):
    
    __call__ = ViewPageTemplateFile('dtwidget.pt')
    
    tag = u'input'
    cssClass = u''
    extra = u''
    _missing = u''

    def evil(self):
        """Allows us to break back into the normal structure so the templates stolen from skin layers still work.  Very evil."""
        from zope.app.component.hooks import getSite; return getSite()  
    
    def getDT(self):
        from Products.ATContentTypes.utils import dt2DT
        try:
            return dt2DT(self._getFormValue())
        except AttributeError:
            return self._missing
    
    def _toFieldValue(self, input):
            if input == self._missing:
                return self.context.missing_value
            else:
                try:
                    DT = DateTime(input)
                except:
                    raise WidgetInputError("Invalid date",input)
                from Products.ATContentTypes.utils import DT2dt
                return DT2dt(DT)
        


from setuptools import setup, find_packages

version = '0.1'

setup(name='collective.dtwidget',
      version=version,
      description="Munges the ATDateTime CalendarWidget into a formlib widget.  Plone only",
      long_description="""Takes the CalendarWidget shipped with Archetypes and Plone and displays the user input section as a formlib widget.  
      Use overrides.zcml to make this the default widget.  Correct functionality requires the CalendarWidget javascripts from core plone being accessible, as well as having
      ATContentTypes installed.  No unit tests yet, this is a proof of concept.
""",
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='formlib widget Datetime',
      author='Matthew Wilkes',
      author_email='matthew.wilkes@circulartriangle.eu',
      url='http://svn.plone.org/svn/plone/collective.dtwidget',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
